@@ -1,12 +1,9 @@
 from achallonge import api
-import asyncio
 
 
-async def index(tournament):
+async def index(tournament, **params):
     """Retrieve a tournament's participant list."""
-    return await api.fetch_and_parse(
-        "GET",
-        f"tournaments/{tournament}/participants")
+    return await api.fetch_and_parse("GET", f"tournaments/{tournament}/participants", **params)
 
 
 async def create(tournament, name, **params):
@@ -14,10 +11,8 @@ async def create(tournament, name, **params):
     params.update({"name": name})
 
     return await api.fetch_and_parse(
-        "POST",
-        f"tournaments/{tournament}/participants",
-        "participant",
-        **params)
+        "POST", f"tournaments/{tournament}/participants", "participant", **params
+    )
 
 
 async def bulk_add(tournament, names, **params):
@@ -34,44 +29,39 @@ async def bulk_add(tournament, names, **params):
     params.update({"name": names})
 
     return await api.fetch_and_parse(
-        "POST",
-        f"tournaments/{tournament}/participants/bulk_add",
-        "participants[]",
-        **params)
+        "POST", f"tournaments/{tournament}/participants/bulk_add", "participants[]", **params
+    )
 
 
 async def show(tournament, participant_id, **params):
     """Retrieve a single participant record for a tournament."""
     return await api.fetch_and_parse(
-        "GET",
-        f"tournaments/{tournament}/participants/{participant_id}",
-        **params)
+        "GET", f"tournaments/{tournament}/participants/{participant_id}", **params
+    )
 
 
 async def update(tournament, participant_id, **params):
     """Update the attributes of a tournament participant."""
     await api.fetch(
-        "PUT",
-        f"tournaments/{tournament}/participants/{participant_id}",
-        "participant",
-        **params)
+        "PUT", f"tournaments/{tournament}/participants/{participant_id}", "participant", **params
+    )
 
 
-async def check_in(tournament, participant_id):
+async def check_in(tournament, participant_id, **params):
     """Checks a participant in."""
     await api.fetch(
-        "POST",
-        f"tournaments/{tournament}/participants/{participant_id}/check_in")
+        "POST", f"tournaments/{tournament}/participants/{participant_id}/check_in", **params
+    )
 
 
-async def undo_check_in(tournament, participant_id):
+async def undo_check_in(tournament, participant_id, **params):
     """Marks a participant as having not checked in."""
     await api.fetch(
-        "POST",
-        f"tournaments/{tournament}/participants/{participant_id}/undo_check_in")
+        "POST", f"tournaments/{tournament}/participants/{participant_id}/undo_check_in", **params
+    )
 
 
-async def destroy(tournament, participant_id):
+async def destroy(tournament, participant_id, **params):
     """Destroys or deactivates a participant.
 
     If tournament has not started, delete a participant, automatically
@@ -81,24 +71,20 @@ async def destroy(tournament, participant_id):
     forfeiting his/her remaining matches.
 
     """
-    await api.fetch(
-        "DELETE",
-        f"tournaments/{tournament}/participants/{participant_id}")
+    await api.fetch("DELETE", f"tournaments/{tournament}/participants/{participant_id}", **params)
 
 
-async def clear(tournament):
+async def clear(tournament, **params):
     """Deletes all participants in a tournament.
     (Only allowed if tournament hasn't started yet)
-    """"
-    await api.fetch(
-        "DELETE",
-        f"tournaments/{tournament}/participants/clear")
+    """
+    await api.fetch("DELETE", f"tournaments/{tournament}/participants/clear", **params)
 
 
-async def randomize(tournament):
+async def randomize(tournament, **params):
     """Randomize seeds among participants.
 
     Only applicable before a tournament has started.
 
     """
-    await api.fetch("POST", f"tournaments/{tournament}/participants/randomize")
+    await api.fetch("POST", f"tournaments/{tournament}/participants/randomize", **params)
