@@ -86,3 +86,12 @@ async def reset(tournament, **params):
 
     """
     return await api.fetch_and_parse("POST", f"tournaments/{tournament}/reset", **params)
+
+async def open_for_predictions(tournament, **params):
+    """Open predictions for a tournament
+    Sets the state of the tournament to start accepting predictions.
+    'prediction_method' must be set to 1 (exponential scoring) or 2 (linear scoring) to use this option.
+    """
+    return await api.fetch_and_parse(
+        "POST", f"tournaments/{tournament}/open_for_predictions", **params
+    )
\ No newline at end of file
